@@ -44,7 +44,7 @@ static void *__init check_function_address(void *ptr, char *symbol)
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 24) || LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 3)
 
 /**
- * probe_kernel_read - Wrapper for kernel_read().
+ * my_kernel_read - Wrapper for kernel_read().
  *
  * @file:   Pointer to "struct file".
  * @offset: Starting position.
@@ -53,7 +53,7 @@ static void *__init check_function_address(void *ptr, char *symbol)
  *
  * Returns return value from kernel_read().
  */
-static int __init probe_kernel_read(struct file *file, unsigned long offset,
+static int __init my_kernel_read(struct file *file, unsigned long offset,
 				    char *addr, unsigned long count)
 {
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 8)
@@ -153,8 +153,8 @@ static void *__init probe_find_symbol(const char *keyline)
 		int len;
 		int offset = 0;
 
-		while ((len = probe_kernel_read(file, offset, buf,
-						PAGE_SIZE - 1)) > 0) {
+		while ((len = my_kernel_read(file, offset, buf,
+					     PAGE_SIZE - 1)) > 0) {
 			char *cp;
 
 			buf[len] = '\0';
@@ -201,9 +201,15 @@ void probe_security_bprm_committed_creds(struct linux_binprm *bprm)
 	do {
 		struct security_hook_list *p;
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 17, 0)
+		hlist_for_each_entry(p, &probe_dummy_security_hook_heads.
+				     bprm_committed_creds, list)
+			p->hook.bprm_committed_creds(bprm);
+#else
 		list_for_each_entry(p, &probe_dummy_security_hook_heads.
 				    bprm_committed_creds, list)
 			p->hook.bprm_committed_creds(bprm);
+#endif
 	} while (0);
 }
 
@@ -231,11 +237,9 @@ static void * __init probe_security_hook_heads_on_arm64(unsigned int *base)
 		 * Find
 		 *   adrp Xd, #imm21
 		 *   add Xd, Xn, #uimm12
-		 *   add Xd, Xn, #uimm12
 		 * sequence.
-		 * But don't mandate the last one in case it was optimized.
 		 */
-		if ((*ip & 0x98000000) != 0x90000000 ||
+		if ((*ip & 0x9F000000) != 0x90000000 ||
 		    (*(ip + 1) & 0xFFC00000) != 0x91000000)
 			continue;
 		tmp = ((unsigned long) ip) & ~0xFFFUL;
@@ -246,12 +250,20 @@ static void * __init probe_security_hook_heads_on_arm64(unsigned int *base)
 		tmp += offset;
 		offset = (*(ip + 1) >> 10) & 0xFFF;
 		tmp += offset;
-		if ((*(ip + 2) & 0xFFC00000) == 0x91000000) {
-			offset = (*(ip + 2) >> 10) & 0xFFF;
+		/*
+		 * Find
+		 *   ldr Xt, Xn, #uimm12
+		 * sequence.
+		 */
+		for (ip += 2; i < 32 - 2; ip++, i++) {
+			if ((*ip & 0xFFC00000) != 0xF9400000)
+				continue;
+			offset = ((*ip >> 10) & 0xFFF) << 3;
 			tmp += offset;
+			ip4ret = (unsigned int *) tmp;
+			return &ip4ret;
 		}
-		ip4ret = (unsigned int *) tmp;
-		return &ip4ret;
+		break;
 	}
 	return NULL;
 }
@@ -513,9 +525,15 @@ struct security_hook_heads * __init probe_security_hook_heads(void)
 	}
 	/* This should be "struct security_hook_heads security_hook_heads;". */
 	shh = ((void *) (*(unsigned long *) cp)) - offset;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 17, 0)
+	hlist_for_each_entry(entry, &shh->bprm_set_creds, list)
+		if (entry->hook.bprm_set_creds == cap)
+			return shh;
+#else
 	list_for_each_entry(entry, &shh->bprm_set_creds, list)
 		if (entry->hook.bprm_set_creds == cap)
 			return shh;
+#endif
 	printk(KERN_ERR "Guessed security_hook_heads is 0x%lx\n",
 	       (unsigned long) shh);
 	return NULL;
